<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2 Gallery plugin.
#
# Copyright (c) 2004-2008 Bruno Hondelatte, and contributors. 
# Many, many thanks to Olivier Meunier and the Dotclear Team.
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------

if (!defined('DC_CONTEXT_ADMIN')) { return; }

/* Icon inside sidebar administration menu */
$_menu['Blog']->addItem(__('Easy Thumb'),'plugin.php?p=easythumb','index.php?pf=easythumb/icon.png',
		preg_match('/plugin.php\?p=easythumb.*$/',$_SERVER['REQUEST_URI']),
		$core->auth->check('usage,contentadmin',$core->blog->id));


# Select methods
$core->rest->addFunction('etGetMediaWithoutThumbs', array('etRest','etGetMediaWithoutThumbs'));
$core->rest->addFunction('etGetNewMedia', array('etRest','etGetNewMedia'));
$core->rest->addFunction('etGetCurrentMedia', array('etRest','etGetCurrentMedia'));

# Update methods
$core->rest->addFunction('etAddImg', array('etRest','etAddImg'));
$core->rest->addFunction('etMediaCreate', array('etRest','etMediaCreate'));
$core->rest->addFunction('etMediaCreateThumbs', array('etRest','etMediaCreateThumbs'));
$core->rest->addFunction('etDeleteOrphanMedia', array('etRest','etDeleteOrphanMedia'));
$core->rest->addFunction('etGetOrphanMediaCount', array('etRest','etGetOrphanMediaCount'));

class etRest 
{
	##################### SELECT REST METHODS ######################


	# Retrieves media not associated to post
	public static function etGetMediaWithoutThumbs($core,$get,$post) {
		if (empty($get['mediaDir'])) {
			throw new Exception('No media dir');
		}
		$core->easythumb = new EasyThumb($core);
		$subdirs=(isset($get['recurse_dir']) && $get['recurse_dir']=="yes");
		$media = $core->easythumb->getMediaWithoutThumbs($get['mediaDir'],$subdirs);
		$rsp = new xmlTag();
		foreach ($media as $id => $file) {
			$mediaTag = new xmlTag('media');
			$mediaTag->id=$id;
			$mediaTag->file=$file;
			$rsp->insertNode($mediaTag);
		}
		return $rsp;
	}

	# Retrieves new media not yet registered in a media_dir
	public static function etGetNewMedia($core,$get,$post) {
		if (empty($get['mediaDir'])) {
			throw new Exception('No media dir');
		}
		$core->easythumb = new EasyThumb($core);
		$dir=$get['mediaDir'];
		$files = $core->easythumb->getNewMedia($dir);
		$rsp = new xmlTag();
		foreach ($files as $file){
			$fileTag = new xmlTag('file');
			$fileTag->name=$file;
			$rsp->insertNode($fileTag);
		}
		return $rsp;
	}
	

	public static function etGetCurrentMedia($core,$get,$post) {
		$core->meta = new dcMeta($core);
		$core->easythumb = new EasyThumb($core);
		$params=array();
		if (empty($get['mediaDir'])) {
			throw new Exception('No media dir');
		}
		$dir=$get['mediaDir'];
		$rs=$core->easythumb->getCurrentMedia($dir);
		$rsp = new xmlTag();
		while ($rs->fetch()) {
			$media = new xmlTag('media');
			$media->id = $rs->media_id;
			$media->name = basename($rs->media_file);
			$rsp->insertNode($media);
		}
		return $rsp;
		
	}


	##################### UPDATE REST METHODS ######################

	# Create a new media
	public static function etMediaCreate($core,$get,$post) {
		if (empty($post['mediaDir'])) {
			throw new Exception('No media dir');
		}
		if (empty($post['mediaName'])) {
			throw new Exception('No media name');
		}
		$core->easythumb = new EasyThumb($core);
		$core->easythumb->chdir($post['mediaDir']);
		$id=$core->easythumb->createFile($post['mediaName']);
		if ($id !== false){
			return $id;
		} else {
			throw new Exception ('Could not create file');
		}
	}

	# Recreate media thumbnails
	public static function etMediaCreateThumbs($core,$get,$post) {
		if (empty($post['mediaId'])) {
			throw new Exception('No media ID');
		}
		$core->easythumb = new EasyThumb($core);
		$core->easythumb->createThumbs((integer)$post['mediaId']);
		return true;
	}


	// Retrieve images with no media associated
	public static function etDeleteOrphanMedia($core,$get,$post) {
		if (empty($post['mediaDir'])) {
			throw new Exception('No media dir');
		}
		$core->meta = new dcMeta($core);
		$core->easythumb = new EasyThumb($core);
		$count = $core->easythumb->deleteOrphanMedia($post['mediaDir']);
		return $count;
	}
	
	// Retrieve images with no media associated
	public static function etGetOrphanMediaCount($core,$get,$post) {
		if (empty($get['mediaDir'])) {
			throw new Exception('No media dir');
		}
		$count_only=false;
		if (!empty($post['count_only'])) {
			$count_only=true;
		}
		$core->meta = new dcMeta($core);
		$core->easythumb = new EasyThumb($core);
		$count = $core->easythumb->deleteOrphanMedia($get['mediaDir'],true);
		return $count;
	}


}

?>