<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2 Gallery plugin.
#
# Copyright (c) 2004-2008 Bruno Hondelatte, and contributors. 
# Many, many thanks to Olivier Meunier and the Dotclear Team.
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------

/**
 * Main Gallery class
 *
 * Handles database back-end requests to retrieve or update images as well as posts
 * 
 * @uses dcMedia
 * @package Gallery
 */
class EasyThumb extends dcMedia
{



	/** 
		### IMAGES & MEDIA MAINTENANCE RETRIEVAL ###
	*/
	/* Image handlers
	------------------------------------------------------- */

	/**
	 * getMediaForGalItems 
	 *
	 * Creates thumbnails for a given media
	 * 
	 * @param rs $cur current media item
	 * @param String $f file name
	 * @param boolean $force if true, force thumbnail regeneration
	 * @access public
	 * @return void
	 */
	public function imageThumbCreate($cur,$f, $force=true)
	{
		$file = $this->pwd.'/'.$f;
		
		if (!file_exists($file)) {
			return false;
		}
		
		$p = path::info($file);
		$thumb = sprintf($this->thumb_tp,$p['dirname'],$p['base'],'%s');
		
		try
		{
			$img = new imageTools();
			$img->loadImage($file);
			
			$w = $img->getW();
			$h = $img->getH();
			if ($force) {
				$this->imageThumbRemove($f);
			}
			
			foreach ($this->thumb_sizes as $suffix => $s) {
				$thumb_file = sprintf($thumb,$suffix);
				if (!$force && file_exists($thumb_file))
					continue;
				if ($s[0] > 0 && ($suffix == 'sq' || $w > $s[0] || $h > $s[0])) {
					$img->resize($s[0],$s[0],$s[1]);
					$img->output('jpeg', $thumb_file, $this->core->blog->settings->easythumb->easythumb_thumb_quality);
				}
			}
			$img->close();
		}
		catch (Exception $e)
		{
			if ($cur === null) { # Called only if cursor is null (public call)
				throw $e;
			}
		}
	}


	/**
	 * getNewMedia 
	 * 
	 * Retrieve media not yet created in a given directory
	 *
	 * @param mixed $media_dir  the media directory to scan
	 * @access public
	 * @return array list of new media file names
	 */
	function getNewMedia($media_dir) {
		$strReq =
		'SELECT media_file, media_id, media_path, media_title, media_meta, media_dt, '.
		'media_creadt, media_upddt, media_private, user_id '.
		'FROM '.$this->table.' '.
		"WHERE media_path = '".$this->path."' ".
		"AND media_dir = '".$this->con->escape($media_dir)."' ";
		
		if (!$this->core->auth->check('media_admin',$this->core->blog->id))
		{
			$strReq .= 'AND (media_private <> 1 ';
			
			if ($this->core->auth->userID()) {
				$strReq .= "OR user_id = '".$this->con->escape($this->core->auth->userID())."'";
			}
			$strReq .= ') ';
		}
		
		$strReq .= 'ORDER BY LOWER(media_file) ASC';
		
		$rs = $this->con->select($strReq);
		
		$this->chdir($media_dir);
		filemanager::getDir();
		
		$p_dir = $this->dir;
		
		$f_reg = array();
		$res=array();
		
		while ($rs->fetch())
		{
			# File in subdirectory, forget about it!
			if (dirname($rs->media_file) != '.' && dirname($rs->media_file) != $this->relpwd) {
				continue;
			}
			
			if ($this->inFiles($rs->media_file))
			{
				$f_reg[$rs->media_file] = 1;
			}
		}
		
		
		# Check files that don't exist in database and create them
		foreach ($p_dir['files'] as $f)
		{
			if (!isset($f_reg[$f->relname])) {
				$res[]=$f->basename;
			}
		}
		return $res;
	}

	/**
	 * getCurrentMedia
	 * 
	 * Retrieve media already created in a given directory
	 *
	 * @param mixed $media_dir  the media directory to scan
	 * @access public
	 * @return array list of media 
	 */
	function getCurrentMedia($media_dir) {
		$strReq =
		'SELECT media_file, media_id, media_path, media_title, media_meta, media_dt, '.
		'media_creadt, media_upddt, media_private, user_id '.
		'FROM '.$this->table.' '.
		"WHERE media_path = '".$this->path."' ".
		"AND media_dir = '".$this->con->escape($media_dir)."' ";
		
		if (!$this->core->auth->check('media_admin',$this->core->blog->id))
		{
			$strReq .= 'AND (media_private <> 1 ';
			
			if ($this->core->auth->userID()) {
				$strReq .= "OR user_id = '".$this->con->escape($this->core->auth->userID())."'";
			}
			$strReq .= ') ';
		}
		
		$strReq .= 'ORDER BY LOWER(media_file) ASC';
		
		$rs = $this->con->select($strReq);
		return $rs;
	}


	/**
	 * getMediaWithoutThumbs 
	 *
	 * Retrieve media with no thumbnails in the given directory
	 * 
	 * @param mixed $media_dir  the media directory to scan
	 * @access public
	 * @return array the list of media IDs
	 */
	function getMediaWithoutThumbs($media_dir) {
		$this->chdir($media_dir);
		$this->getDir('image');
		$dir =& $this->dir;
		$items=array_values($dir['files']);
		$ids=array();
		foreach ($items as $item) {
			if (empty($item->media_thumb)) {
				$ids[$item->media_id]=$item->basename;
			} else {
				foreach ($this->thumb_sizes as $suffix => $s) {
					if (empty($item->media_thumb[$suffix])) {
						$ids[$item->media_id]=$item->basename;
						continue(2);
					}
				}
			}
		}
		return $ids;
	}

	/** 
		### IMAGES & MEDIA ORPHANS REMOVAL ###
	*/


	/**
	 * deleteOrphanMedia 
	 *
	 * Delete media entries with no physical files associated
	 * 
	 * @param string $media_dir the media directory to scan
	 * @param boolean $count_only if true, only return the number of orphan media
	 * @access public
	 * @return void
	 */
	function deleteOrphanMedia($media_dir, $count_only=false) {
		$strReq =
		'SELECT media_file, media_id, media_path, media_title, media_meta, media_dt, '.
		'media_creadt, media_upddt, media_private, user_id '.
		'FROM '.$this->table.' '.
		"WHERE media_path = '".$this->path."' ".
		"AND media_dir = '".$this->con->escape($media_dir)."' ";
		
		if (!$this->core->auth->check('media_admin',$this->core->blog->id))
		{
			$strReq .= 'AND (media_private <> 1 ';
			
			if ($this->core->auth->userID()) {
				$strReq .= "OR user_id = '".$this->con->escape($this->core->auth->userID())."'";
			}
			$strReq .= ') ';
		}
		$rs = $this->con->select($strReq);
		$count=0;
		while ($rs->fetch())
		{
			if (!file_exists($this->pwd."/".$rs->media_file)) {
				# Physical file does not exist remove it from DB
				# Because we don't want to erase everything on
				# dotclear upgrade, do it only if there are files
				# in directory and directory is root
				if ($count_only) {
					$count++;
				} else {
					$this->con->execute(
						'DELETE FROM '.$this->table.' '.
						"WHERE media_path = '".$this->con->escape($this->path)."' ".
						"AND media_file = '".$this->con->escape($rs->media_file)."' "
					);
				}
			}
		}
		return $count;
	}

	/** 
		### IMAGES & MEDIA CREATION ###
	*/
	/**
	 * getExifDate 
	 *
	 * Returns the exif date from media metadata
	 * 
	 * @param simpleXML $meta metadata
	 * @param date $default default date to return if exif date is not readable
	 * @access public
	 * @return string the exif date (converted to string)
	 */
	function getExifDate($meta,$default) {
		$post_dt=$default;
		if ($meta !== false){
			if (count($meta->xpath('DateTimeOriginal'))) {
				if ($meta->DateTimeOriginal != '') {
					$media_ts = strtotime($meta->DateTimeOriginal);
					$o = dt::getTimeOffset($this->core->auth->getInfo('user_tz'),$media_ts);
					$post_dt = dt::str('%Y-%m-%d %H:%M:%S',$media_ts+$o);
				}
			}
		}
		return $post_dt;
	}


	/**
	 * createThumbs 
	 * 
	 * creates all thumbs for a given media
	 * given its id
	 *
	 * @param string $media_id  the media id
	 * @access public
	 * @return void
	 */
	public function createThumbs($media_id,$force=true) {
		$media = $this->getFile($media_id);
		if ($media == null) {
			throw new Exception (__('Media not found'));
		}
		$this->chdir(dirname($media->relname));
		if ($media->media_type == 'image')
			$this->imageThumbCreate($media,$media->basename,$force);
	}



	/**
	 * readMedia 
	 * 
	 * Reads a media from a record in database
	 *
	 * @param record $rs  the media record
	 * @access public
	 * @return record the decorated record
	 */
	public function readMedia ($rs) {
		return $this->fileRecord($rs);
	}

}
?>
